package src.de.dhbw_ka.probe_pe.darts_counter;

/**
 * Class representing a player in the darts game
 */
public class Player {
  /**
   * Name of the player
   */
  private String name;
  /**
   * Amount of darts the player has already thrown
   */
  private int countDartsThrown = 0;
  /**
   * Array of visits the player has already done (max 10)
   * 
   * @see Visit
   */
  private Visit[] visits = new Visit[10];

  /**
   * Initiates a new player
   * 
   * @param name Name of the player
   */
  public Player(String name) {
    this.name = name;
  }

  /**
   * Gets the players name
   * 
   * @return name
   */
  public String getName() {
    return name;
  }

  /**
   * Sets the players name
   * 
   * @param name
   */
  public void setName(String name) {
    this.name = name;
  }

  /**
   * Get the amount of darts this player has thrown
   * 
   * @return amount of darts
   */
  public int getCountDartsThrown() {
    return countDartsThrown;
  }

  /**
   * Gets the amount of visits the player has already done
   * 
   * @return already done visits
   */
  public int getVisitsCount() {
    int visitCount = 0;
    for (Visit v : visits) {
      if (v == null)
        continue;
      visitCount++;
    }
    return visitCount;
  }

  /**
   * Gets the remaining points of this player
   * 
   * @return remaining points
   */
  public int getRemainingPoints() {
    int pointsRemaining = 501;
    for (Visit v : visits) {
      if (v == null)
        continue;
      pointsRemaining -= v.getValue();
    }
    return pointsRemaining;
  }

  /**
   * Attempts to add a visit
   * 
   * @param visit The visit to add
   * @return success of the visit
   * @see Visit
   */
  public boolean addVisit(Visit visit) {
    /**
     * Count up the darts thrown
     */
    this.countDartsThrown += visit.getFields().length;

    /**
     * Don't allow visits to have a higher value than the remaining points
     */
    if (visit.getValue() > this.getRemainingPoints())
      return false;

    /**
     * Only allow finishing the game with a double field
     */
    if (visit.getValue() == this.getRemainingPoints() && !visit.getLastField().getDoubleField())
      return false;

    /**
     * Don't allow a player to get exactly 1 point
     */
    if (this.getRemainingPoints() - visit.getValue() == 1)
      return false;

    /**
     * Add visit to array
     */
    int currentVisitCount = this.getVisitsCount();
    if (currentVisitCount >= 10)
      return false;

    this.visits[currentVisitCount] = visit;

    return true;
  }

  @Override
  public String toString() {
    return this.name + ", " + this.getRemainingPoints() + " points remaining.";
  }
}
