package src.de.dhbw_ka.probe_pe.darts_counter;

/**
 * Class representing a dart visit
 */
public class Visit {
  /**
   * Array of all the fields hit in this visit
   * 
   * @see Field
   */
  private Field[] fields;

  /**
   * Create a new Visit instance for the hit fields
   * 
   * @param fields array of fields hit (must be less or eqal to 3)
   * @see Field
   */
  public Visit(Field[] fields) {
    if (fields.length > 3)
      throw new IllegalArgumentException("Thrown too many darts for one visit!");

    this.fields = fields;
  }

  /**
   * 
   * @return All the fields hit in this visit
   * @see Field
   */
  public Field[] getFields() {
    return fields;
  }

  /**
   * Calculate the value of this visit
   * 
   * @return value of the visit
   */
  public int getValue() {
    int value = 0;
    for (Field f : fields) {
      if (f == null)
        continue;
      value += f.getValue();
    }
    return value;
  }

  /**
   * Returns the last field for checking if the player finished with a double
   * field
   * 
   * @return last field of the visit
   * @see Field
   */
  public Field getLastField() {
    if (fields.length == 0)
      return null;
    return fields[fields.length - 1];
  }
}
